************
Installation
************

**easyScience** requires Python 3.7 or above.

Install via ``pip``
-------------------

The easiest way of obtaining easyCore and using it in your project is via pip. You can install directly by using:

.. code-block:: console

    $ pip install easyscience

Install as an easyCore developer
--------------------------------

You can obtain the latest development source from our `Github repository
<https://github.com/easyScience/easyCore>`_.:

.. code-block:: console

    $ git clone https://github.com/easyScience/easyScience.git
    $ cd easyScience

And install via pip:

.. code-block:: console

    $ pip install -r requirements.txt
    $ pip install -e .

.. installation-end-content